sqlobject.include.tests.test_hashcol module — SQLObject 3.9.1 documentation

# sqlobject.include.tests.test_hashcol module

class `sqlobject.include.tests.test_hashcol.` `HashTest`(**kw)

  Bases: `sqlobject.main.SQLObject`

  classmethod `bySo_count`(val, connection=None)
  property `col1`
  property `col2`
  `j` = hash_test
  `q` = hash_test
  property `so_count`
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.include.tests.test_hashcol.HashTest`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'hash_test'

`sqlobject.include.tests.test_hashcol.` `md5_str`(x)

`sqlobject.include.tests.test_hashcol.` `setup`()

`sqlobject.include.tests.test_hashcol.` `sha256_str`(x)

`sqlobject.include.tests.test_hashcol.` `test_create`()

`sqlobject.include.tests.test_hashcol.` `test_select`()